@@ -1,5 +1,4 @@
-import larq_zoo.literature as literature
-import larq_zoo.sota as sota
+from larq_zoo import literature, sota
 from larq_zoo.core.utils import decode_predictions
 from larq_zoo.training import datasets
 from larq_zoo.training.data import preprocess_input
